==> libqt4pas_2.4.orig.tar.gz: splitbuild-qt4pas-V2.4_Qt4.5.3/src/qfontinfo_c.h <==
//******************************************************************************
//  Copyright (c) 2005-2011 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************


#ifndef QFONTINFO_C_H
#define QFONTINFO_C_H

#include <QtGui>
#include "pascalbind.h"

C_EXPORT QFontInfoH QFontInfo_create(const QFontH p1);
C_EXPORT void QFontInfo_destroy(QFontInfoH handle);
C_EXPORT QFontInfoH QFontInfo_create2(const QFontInfoH p1);
C_EXPORT void QFontInfo_family(QFontInfoH handle, PWideString retval);
C_EXPORT int QFontInfo_pixelSize(QFontInfoH handle);
C_EXPORT int QFontInfo_pointSize(QFontInfoH handle);
C_EXPORT qreal QFontInfo_pointSizeF(QFontInfoH handle);
C_EXPORT bool QFontInfo_italic(QFontInfoH handle);
C_EXPORT QFont::Style QFontInfo_style(QFontInfoH handle);
C_EXPORT int QFontInfo_weight(QFontInfoH handle);
C_EXPORT bool QFontInfo_bold(QFontInfoH handle);
C_EXPORT bool QFontInfo_underline(QFontInfoH handle);
C_EXPORT bool QFontInfo_overline(QFontInfoH handle);
C_EXPORT bool QFontInfo_strikeOut(QFontInfoH handle);
C_EXPORT bool QFontInfo_fixedPitch(QFontInfoH handle);
C_EXPORT QFont::StyleHint QFontInfo_styleHint(QFontInfoH handle);
C_EXPORT bool QFontInfo_rawMode(QFontInfoH handle);
C_EXPORT bool QFontInfo_exactMatch(QFontInfoH handle);

#endif

==> libqt4pas_2.5.orig.tar.gz: splitbuild-qt4pas-V2.5_Qt4.5.3/src/qfontinfo_c.h <==
//******************************************************************************
//  Copyright (c) 2005-2011 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************


#ifndef QFONTINFO_C_H
#define QFONTINFO_C_H

#include <QtGui>
#include "pascalbind.h"

C_EXPORT QFontInfoH QFontInfo_create(const QFontH AnonParam1);
C_EXPORT void QFontInfo_destroy(QFontInfoH handle);
C_EXPORT QFontInfoH QFontInfo_create2(const QFontInfoH AnonParam1);
C_EXPORT void QFontInfo_family(QFontInfoH handle, PWideString retval);
C_EXPORT int QFontInfo_pixelSize(QFontInfoH handle);
C_EXPORT int QFontInfo_pointSize(QFontInfoH handle);
C_EXPORT qreal QFontInfo_pointSizeF(QFontInfoH handle);
C_EXPORT bool QFontInfo_italic(QFontInfoH handle);
C_EXPORT QFont::Style QFontInfo_style(QFontInfoH handle);
C_EXPORT int QFontInfo_weight(QFontInfoH handle);
C_EXPORT bool QFontInfo_bold(QFontInfoH handle);
C_EXPORT bool QFontInfo_underline(QFontInfoH handle);
C_EXPORT bool QFontInfo_overline(QFontInfoH handle);
C_EXPORT bool QFontInfo_strikeOut(QFontInfoH handle);
C_EXPORT bool QFontInfo_fixedPitch(QFontInfoH handle);
C_EXPORT QFont::StyleHint QFontInfo_styleHint(QFontInfoH handle);
C_EXPORT bool QFontInfo_rawMode(QFontInfoH handle);
C_EXPORT bool QFontInfo_exactMatch(QFontInfoH handle);

#endif
